@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -49,8 +49,9 @@
 WX_DEFINE_OBJARRAY( guAlbumBrowserItemArray );
 
 #define guALBUMBROWSER_REFRESH_DELAY            60
-#define guALBUMBROWSER_GRID_SIZE_WIDTH          150
-#define guALBUMBROWSER_GRID_SIZE_HEIGHT         180
+#define guALBUMBROWSER_GRID_SIZE_WIDTH          140
+//#define guALBUMBROWSER_GRID_SIZE_HEIGHT         180
+static int guALBUMBROWSER_GRID_SIZE_HEIGHT = -1;
 
 #define guALBUMBROWSER_TIMER_ID_REFRESH         3
 #define guALBUMBROWSER_TIMER_ID_BITMAP_CLICKED  4
@@ -138,32 +139,33 @@ guUpdateAlbumDetails::ExitCode guUpdateAlbumDetails::Entry()
 // guAlbumBrowserItemPanel
 // -------------------------------------------------------------------------------- //
 guAlbumBrowserItemPanel::guAlbumBrowserItemPanel( wxWindow * parent, const int index,
-    guAlbumBrowserItem * albumitem ) : wxPanel( parent, wxID_ANY )
+    guAlbumBrowserItem * albumitem ) : wxPanel( parent, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxWANTS_CHARS )
 {
     m_AlbumBrowserItem = albumitem;
     m_AlbumBrowser = ( guAlbumBrowser * ) parent;
 
     wxFont CurrentFont = GetFont();
+
     // GUI
 	m_MainSizer = new wxBoxSizer( wxVERTICAL );
 
-	m_Bitmap = new wxStaticBitmap( this, wxID_ANY, wxNullBitmap, wxDefaultPosition, wxSize( 100, 100 ), 0 );
-	m_MainSizer->Add( m_Bitmap, 0, wxTOP|wxRIGHT|wxLEFT, 5 );
+	m_Bitmap = new wxStaticBitmap( this, wxID_ANY, wxNullBitmap, wxDefaultPosition, wxSize( GUCOVER_IMAGE_SIZE, GUCOVER_IMAGE_SIZE ) );
+	m_MainSizer->Add( m_Bitmap, 0, wxRIGHT, 2 );
 
 	m_AlbumLabel = new guAutoScrollText( this, wxEmptyString );
 	CurrentFont.SetWeight( wxFONTWEIGHT_BOLD );
 	CurrentFont.SetPointSize( CurrentFont.GetPointSize() - 1 );
 	m_AlbumLabel->SetFont( CurrentFont );
-	m_MainSizer->Add( m_AlbumLabel, 0, wxRIGHT|wxLEFT|wxEXPAND, 5 );
+	m_MainSizer->Add( m_AlbumLabel, 0, wxRIGHT|wxEXPAND, 5 );
 
 	m_ArtistLabel = new guAutoScrollText( this, wxEmptyString );
 	CurrentFont.SetWeight( wxFONTWEIGHT_NORMAL );
 	m_ArtistLabel->SetFont( CurrentFont );
-	m_MainSizer->Add( m_ArtistLabel, 0, wxRIGHT|wxLEFT|wxEXPAND, 5 );
+	m_MainSizer->Add( m_ArtistLabel, 0, wxRIGHT|wxEXPAND, 5 );
 
 	m_TracksLabel = new guAutoScrollText( this, wxEmptyString );
 	m_TracksLabel->SetFont( CurrentFont );
-	m_MainSizer->Add( m_TracksLabel, 0, wxBOTTOM|wxRIGHT|wxLEFT|wxEXPAND, 5 );
+	m_MainSizer->Add( m_TracksLabel, 0, wxRIGHT|wxEXPAND, 5 );
 
 	SetSizer( m_MainSizer );
 	Layout();
@@ -203,38 +205,17 @@ guAlbumBrowserItemPanel::guAlbumBrowserItemPanel( wxWindow * parent, const int i
     Connect( ID_ALBUMBROWSER_COVER_BEGINDRAG, wxEVT_COMMAND_MENU_SELECTED, wxMouseEventHandler( guAlbumBrowserItemPanel::OnCoverBeginDrag ), NULL, this );
 
 	Connect( wxEVT_TIMER, wxTimerEventHandler( guAlbumBrowserItemPanel::OnTimer ), NULL, this );
+
+    Connect( wxEVT_KEY_DOWN, wxKeyEventHandler( guAlbumBrowser::OnKeyDown ), NULL, m_AlbumBrowser );
+    m_Bitmap->Connect( wxEVT_KEY_DOWN, wxKeyEventHandler( guAlbumBrowser::OnKeyDown ), NULL, m_AlbumBrowser );
+    m_AlbumLabel->Connect( wxEVT_KEY_DOWN, wxKeyEventHandler( guAlbumBrowser::OnKeyDown ), NULL, m_AlbumBrowser );
+    m_ArtistLabel->Connect( wxEVT_KEY_DOWN, wxKeyEventHandler( guAlbumBrowser::OnKeyDown ), NULL, m_AlbumBrowser );
+    m_TracksLabel->Connect( wxEVT_KEY_DOWN, wxKeyEventHandler( guAlbumBrowser::OnKeyDown ), NULL, m_AlbumBrowser );
 }
 
 // -------------------------------------------------------------------------------- //
 guAlbumBrowserItemPanel::~guAlbumBrowserItemPanel()
 {
-    Disconnect( wxEVT_CONTEXT_MENU, wxContextMenuEventHandler( guAlbumBrowserItemPanel::OnContextMenu ), NULL, this );
-
-    Disconnect( ID_COMMANDS_BASE, ID_COMMANDS_BASE + guCOMMANDS_MAXCOUNT, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( guAlbumBrowserItemPanel::OnCommandClicked ) );
-    Disconnect( ID_LINKS_BASE, ID_LINKS_BASE + guLINKS_MAXCOUNT, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( guAlbumBrowserItemPanel::OnSearchLinkClicked ) );
-
-	m_Bitmap->Disconnect( wxEVT_LEFT_DCLICK, wxMouseEventHandler( guAlbumBrowserItemPanel::OnAlbumDClicked ), NULL, this );
-
-    Disconnect( ID_ALBUMBROWSER_PLAY, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( guAlbumBrowserItemPanel::OnPlayClicked ), NULL, this );
-    Disconnect( ID_ALBUMBROWSER_ENQUEUE_AFTER_ALL, ID_ALBUMBROWSER_ENQUEUE_AFTER_ARTIST, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( guAlbumBrowserItemPanel::OnEnqueueClicked ), NULL, this );
-    Disconnect( ID_ALBUMBROWSER_EDITLABELS, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( guAlbumBrowserItemPanel::OnAlbumEditLabelsClicked ), NULL, this );
-    Disconnect( ID_ALBUMBROWSER_EDITTRACKS, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( guAlbumBrowserItemPanel::OnAlbumEditTracksClicked ), NULL, this );
-    Disconnect( ID_ALBUMBROWSER_COPYTOCLIPBOARD, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( guAlbumBrowserItemPanel::OnCopyToClipboard ), NULL, this );
-    Disconnect( ID_ALBUM_SELECTNAME, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( guAlbumBrowserItemPanel::OnAlbumSelectName ), NULL, this );
-    Disconnect( ID_ARTIST_SELECTNAME, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( guAlbumBrowserItemPanel::OnArtistSelectName ), NULL, this );
-
-    Disconnect( ID_ALBUMBROWSER_SEARCHCOVER, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( guAlbumBrowserItemPanel::OnAlbumDownloadCoverClicked ), NULL, this );
-    Disconnect( ID_ALBUMBROWSER_SELECTCOVER, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( guAlbumBrowserItemPanel::OnAlbumSelectCoverClicked ), NULL, this );
-    Disconnect( ID_ALBUMBROWSER_DELETECOVER, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( guAlbumBrowserItemPanel::OnAlbumDeleteCoverClicked ), NULL, this );
-    Disconnect( ID_ALBUMBROWSER_EMBEDCOVER, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( guAlbumBrowserItemPanel::OnAlbumEmbedCoverClicked ), NULL, this );
-    Disconnect( ID_COPYTO_BASE, ID_COPYTO_BASE + guCOPYTO_MAXCOUNT, wxEVT_COMMAND_MENU_SELECTED, wxCommandEventHandler( guAlbumBrowserItemPanel::OnAlbumCopyToClicked ), NULL, this );
-
-	m_Bitmap->Disconnect( wxEVT_LEFT_DOWN, wxMouseEventHandler( guAlbumBrowserItemPanel::OnMouse ), NULL, this );
-	m_Bitmap->Disconnect( wxEVT_LEFT_UP, wxMouseEventHandler( guAlbumBrowserItemPanel::OnMouse ), NULL, this );
-	m_Bitmap->Disconnect( wxEVT_MOTION, wxMouseEventHandler( guAlbumBrowserItemPanel::OnMouse ), NULL, this );
-
-    Disconnect( ID_ALBUMBROWSER_BEGINDRAG, wxEVT_COMMAND_MENU_SELECTED, wxMouseEventHandler( guAlbumBrowserItemPanel::OnBeginDrag ), NULL, this );
-    Disconnect( ID_ALBUMBROWSER_COVER_BEGINDRAG, wxEVT_COMMAND_MENU_SELECTED, wxMouseEventHandler( guAlbumBrowserItemPanel::OnCoverBeginDrag ), NULL, this );
 }
 
 // -------------------------------------------------------------------------------- //
@@ -315,7 +296,7 @@ void guAlbumBrowserItemPanel::OnContextMenu( wxContextMenuEvent &event )
     }
 
 
-    if( m_AlbumBrowserItem->m_AlbumId != ( size_t ) wxNOT_FOUND )
+    if( m_AlbumBrowserItem->m_AlbumId != ( unsigned int ) wxNOT_FOUND )
     {
         int ContextMenuFlags = m_AlbumBrowser->GetContextMenuFlags();
 
@@ -603,30 +584,37 @@ void guAlbumBrowserItemPanel::OnMouse( wxMouseEvent &event )
     event.Skip();
 }
 
+// -------------------------------------------------------------------------------- //
+int guAlbumBrowserItemPanel::GetDragFiles( guDataObjectComposite * files )
+{
+    guTrackArray Tracks;
+    wxArrayString Filenames;
+    int Index;
+    int Count = m_AlbumBrowser->GetAlbumTracks( m_AlbumBrowserItem->m_AlbumId, &Tracks );
+    for( Index = 0; Index < Count; Index++ )
+    {
+        if( Tracks[ Index ].m_Offset )
+            continue;
+        Filenames.Add( guFileDnDEncode( Tracks[ Index ].m_FileName ) );
+    }
+    files->SetTracks( Tracks );
+    files->SetFiles( Filenames );
+    return Count;
+}
+
 // -------------------------------------------------------------------------------- //
 void guAlbumBrowserItemPanel::OnBeginDrag( wxMouseEvent &event )
 {
     if( !m_AlbumBrowserItem )
         return;
 
-    int Index;
-    int Count;
-    //guLogMessage( wxT( "On BeginDrag event..." ) );
-    guTrackArray Tracks;
+    guDataObjectComposite Files;
 
-    m_AlbumBrowser->GetAlbumTracks( m_AlbumBrowserItem->m_AlbumId, &Tracks );
-    if( ( Count = Tracks.Count() ) )
+    if( GetDragFiles( &Files ) )
     {
-        m_AlbumBrowser->NormalizeTracks( &Tracks, true );
-        wxFileDataObject Files;
-        for( Index = 0; Index < Count; Index++ )
-        {
-            Files.AddFile( Tracks[ Index ].m_FileName );
-        }
-
         wxDropSource source( Files, this );
 
-        wxDragResult Result = source.DoDragDrop( wxDrag_CopyOnly );
+        wxDragResult Result = source.DoDragDrop();
         if( Result )
         {
         }
@@ -700,7 +688,7 @@ void guAlbumBrowserItemPanel::OnTimer( wxTimerEvent &event )
 // guAlbumBrowser
 // -------------------------------------------------------------------------------- //
 guAlbumBrowser::guAlbumBrowser( wxWindow * parent, guMediaViewer * mediaviewer ) :
-    wxPanel( parent, wxID_ANY ),
+    wxPanel( parent, wxID_ANY, wxDefaultPosition, wxDefaultSize, wxWANTS_CHARS ),
     m_RefreshTimer( this, guALBUMBROWSER_TIMER_ID_REFRESH ),
     m_BitmapClickTimer( this, guALBUMBROWSER_TIMER_ID_BITMAP_CLICKED )
 {
@@ -722,6 +710,12 @@ guAlbumBrowser::guAlbumBrowser( wxWindow * parent, guMediaViewer * mediaviewer )
     guConfig * Config = ( guConfig * ) guConfig::Get();
     Config->RegisterObject( this );
 
+
+    if( guALBUMBROWSER_GRID_SIZE_HEIGHT == -1 )
+    {
+        CalculateMaxItemHeight();
+    }
+
     CreateControls();
 
     CreateAcceleratorTable();
@@ -781,7 +775,7 @@ void guAlbumBrowser::CreateControls( void )
 
 	m_NavSlider = new wxSlider( this, wxID_ANY, 0, 0, 1, wxDefaultPosition, wxDefaultSize, wxSL_HORIZONTAL );
 	m_NavSlider->SetFocus();
-	NavigatorSizer->Add( m_NavSlider, 1, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxBOTTOM|wxRIGHT|wxLEFT, 5 );
+	NavigatorSizer->Add( m_NavSlider, 1, wxEXPAND|wxALIGN_CENTER_HORIZONTAL|wxRIGHT|wxLEFT, 5 );
 
 	m_AlbumBrowserSizer->Add( NavigatorSizer, 0, wxEXPAND, 5 );
 
@@ -794,46 +788,46 @@ void guAlbumBrowser::CreateControls( void )
 
 	m_BigCoverSizer->Add( 0, 0, 1, wxEXPAND, 5 );
 
-	wxBoxSizer * BigCoverCenterSizer = new wxBoxSizer( wxHORIZONTAL );
+	wxFlexGridSizer * BigCoverCenterSizer = new wxFlexGridSizer( 1, 5, 0, 0 );
+	BigCoverCenterSizer->AddGrowableCol( 0 );
+	BigCoverCenterSizer->AddGrowableCol( 2 );
+	BigCoverCenterSizer->AddGrowableCol( 3 );
+	BigCoverCenterSizer->AddGrowableCol( 4 );
+	BigCoverCenterSizer->SetFlexibleDirection( wxBOTH );
+	BigCoverCenterSizer->SetNonFlexibleGrowMode( wxFLEX_GROWMODE_SPECIFIED );
 
 	BigCoverCenterSizer->Add( 0, 0, 2, wxEXPAND, 5 );
 
 	wxBoxSizer * BigCoverSizer = new wxBoxSizer( wxVERTICAL );
 
-	m_BigCoverBitmap = new wxStaticBitmap( this, wxID_ANY, wxNullBitmap, wxDefaultPosition, wxSize( 300,300 ), 0 );
+	m_BigCoverBitmap = new wxStaticBitmap( this, wxID_ANY, wxNullBitmap, wxDefaultPosition, wxSize( 300, 300 ), 0 );
 	BigCoverSizer->Add( m_BigCoverBitmap, 0, wxALIGN_CENTER_HORIZONTAL, 5 );
 
-	m_BigCoverAlbumLabel = new wxStaticText( this, wxID_ANY, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0 );
-	m_BigCoverAlbumLabel->Wrap( -1 );
+	m_BigCoverAlbumLabel = new guAutoScrollText( this, wxEmptyString, wxSize( 290, -1 ) );
 	wxFont CurFont = GetFont();
 	CurFont.SetWeight( wxFONTWEIGHT_BOLD );
 	m_BigCoverAlbumLabel->SetFont( CurFont );
 	BigCoverSizer->Add( m_BigCoverAlbumLabel, 0, wxALIGN_CENTER_HORIZONTAL|wxTOP|wxRIGHT|wxLEFT, 5 );
 
-	m_BigCoverArtistLabel = new wxStaticText( this, wxID_ANY, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0 );
-	m_BigCoverArtistLabel->Wrap( -1 );
+	m_BigCoverArtistLabel = new guAutoScrollText( this, wxEmptyString, wxSize( 290, -1 ) );
 	//m_BigCoverArtistLabel->SetFont( wxFont( wxNORMAL_FONT->GetPointSize(), 70, 90, 90, false, wxEmptyString ) );
 	BigCoverSizer->Add( m_BigCoverArtistLabel, 0, wxALIGN_CENTER_HORIZONTAL|wxRIGHT|wxLEFT, 5 );
 
-	m_BigCoverDetailsLabel = new wxStaticText( this, wxID_ANY, wxEmptyString, wxDefaultPosition, wxDefaultSize, 0 );
-	m_BigCoverDetailsLabel->Wrap( -1 );
+	m_BigCoverDetailsLabel = new guAutoScrollText( this, wxEmptyString, wxSize( 290, -1 ) );
     CurFont = GetFont();
 	CurFont.SetPointSize( CurFont.GetPointSize() - 2 );
 	m_BigCoverDetailsLabel->SetFont( CurFont );
 	BigCoverSizer->Add( m_BigCoverDetailsLabel, 0, wxALIGN_CENTER_HORIZONTAL|wxBOTTOM|wxRIGHT|wxLEFT, 5 );
 
-	BigCoverCenterSizer->Add( BigCoverSizer, 0, wxEXPAND, 5 );
+	BigCoverCenterSizer->Add( BigCoverSizer, 1, wxEXPAND|wxRIGHT|wxLEFT, 5 );
 
 	BigCoverCenterSizer->Add( 0, 0, 1, wxEXPAND, 5 );
 
-	wxBoxSizer * BigCoverTracksSizer = new wxBoxSizer( wxVERTICAL );
-
 	m_BigCoverTracksListBox = new wxListBox( this, wxID_ANY, wxDefaultPosition, wxDefaultSize, 0, NULL, wxLB_MULTIPLE );
 	m_BigCoverTracksListBox->SetBackgroundColour( m_BigCoverDetailsLabel->GetBackgroundColour() );
-	//m_BigCoverTracksListBox->SetMaxSize( wxSize( 450, -1 ) );
-	BigCoverTracksSizer->Add( m_BigCoverTracksListBox, 1, 0, 5 );
+	m_BigCoverTracksListBox->SetMaxSize( wxSize( 450, -1 ) );
 
-	BigCoverCenterSizer->Add( BigCoverTracksSizer, 0, wxALIGN_CENTER_VERTICAL|wxEXPAND, 5 );
+	BigCoverCenterSizer->Add( m_BigCoverTracksListBox, 1, wxALIGN_CENTER_HORIZONTAL|wxEXPAND|wxRIGHT, 5 );
 
 	BigCoverCenterSizer->Add( 0, 0, 2, wxEXPAND, 5 );
 
@@ -854,12 +848,14 @@ void guAlbumBrowser::CreateControls( void )
     // ------------------------------------------------------------------------------------------------------------------
 
     this->SetSizer( m_MainSizer );
-	//this->Layout();
+	BigCoverSizer->Layout();
 
 	m_MainSizer->Hide( m_BigCoverSizer, true );
 	m_MainSizer->FitInside( this );
 
     Connect( wxEVT_SIZE, wxSizeEventHandler( guAlbumBrowser::OnChangedSize ), NULL, this );
+    Connect( wxEVT_KEY_DOWN, wxKeyEventHandler( guAlbumBrowser::OnKeyDown ), NULL, this );
+
 	m_NavSlider->Connect( wxEVT_SCROLL_CHANGED, wxScrollEventHandler( guAlbumBrowser::OnChangingPosition ), NULL, this );
 	m_NavSlider->Connect( wxEVT_SCROLL_THUMBTRACK, wxScrollEventHandler( guAlbumBrowser::OnChangingPosition ), NULL, this );
 	Connect( guALBUMBROWSER_TIMER_ID_REFRESH, wxEVT_TIMER, wxTimerEventHandler( guAlbumBrowser::OnRefreshTimer ), NULL, this );
@@ -947,6 +943,17 @@ void guAlbumBrowser::OnGoToSearch( wxCommandEvent &event )
     m_MediaViewer->GoToSearch();
 }
 
+// -------------------------------------------------------------------------------- //
+void guAlbumBrowser::CalculateMaxItemHeight( void )
+{
+    int w;
+    int h;
+    int d;
+    GetTextExtent( wxT("Hg"), &w, &h, &d );
+
+    guALBUMBROWSER_GRID_SIZE_HEIGHT = GUCOVER_IMAGE_SIZE + 4 + ( 3 * h ) + 5;
+}
+
 // -------------------------------------------------------------------------------- //
 void guAlbumBrowser::OnChangedSize( wxSizeEvent &event )
 {
@@ -976,7 +983,7 @@ void guAlbumBrowser::OnChangedSize( wxSizeEvent &event )
                         m_ItemPanels.Add( new guAlbumBrowserItemPanel( this, Index ) );
                         if( m_BigCoverShowed )
                             m_ItemPanels[ Index ]->Hide();
-                        m_AlbumsSizer->Add( m_ItemPanels[ Index ], 1, wxEXPAND|wxALL, 5 );
+                        m_AlbumsSizer->Add( m_ItemPanels[ Index ], 1, wxEXPAND|wxALL, 2 );
                     }
                 }
                 else //if( m_ItemCount < OldCount )
@@ -1012,7 +1019,7 @@ bool guAlbumBrowser::DoTextSearch( const wxString &searchtext )
         m_LastSearchString = searchtext; //m_SearchTextCtrl->GetLineText( 0 );
         if( !m_LastSearchString.IsEmpty() )
         {
-            if( m_LastSearchString.Length() > 1 )
+            if( m_LastSearchString.Length() > 0 )
             {
                 m_TextSearchFilter = guSplitWords( m_LastSearchString );
 
@@ -1120,7 +1127,7 @@ void guAlbumBrowser::SelectAlbum( const int albumid, const bool append, const in
     guTrackArray Tracks;
     wxArrayInt Selections;
     Selections.Add( albumid );
-    if( m_Db->GetAlbumsSongs( Selections, &Tracks ) )
+    if( m_Db->GetAlbumsSongs( Selections, &Tracks, true ) )
     {
         NormalizeTracks( &Tracks );
         if( append )
@@ -1135,7 +1142,7 @@ int guAlbumBrowser::GetAlbumTracks( const int albumid, guTrackArray * tracks )
 {
     wxArrayInt Albums;
     Albums.Add( albumid );
-    return m_Db->GetAlbumsSongs( Albums, tracks );
+    return m_Db->GetAlbumsSongs( Albums, tracks, true );
 }
 
 // -------------------------------------------------------------------------------- //
@@ -1206,7 +1213,7 @@ void guAlbumBrowser::OnCommandClicked( const int cmdid, const int albumid )
             {
                 guTrackArray Songs;
                 wxString SongList = wxEmptyString;
-                if( m_Db->GetAlbumsSongs( Selection, &Songs ) )
+                if( m_Db->GetAlbumsSongs( Selection, &Songs, true ) )
                 {
                     NormalizeTracks( &Songs );
                     count = Songs.Count();
@@ -1325,7 +1332,7 @@ void guAlbumBrowser::OnAlbumCopyToClicked( const int albumid, const int commandi
     wxArrayInt Albums;
     Albums.Add( albumid );
 
-    m_Db->GetAlbumsSongs( Albums, Tracks );
+    m_Db->GetAlbumsSongs( Albums, Tracks, true );
     NormalizeTracks( Tracks );
 
     wxCommandEvent event( wxEVT_COMMAND_MENU_SELECTED, ID_MAINFRAME_COPYTO );
@@ -1418,6 +1425,60 @@ void guAlbumBrowser::OnUpdateDetails( wxCommandEvent &event )
     m_AlbumItemsMutex.Unlock();
 }
 
+// -------------------------------------------------------------------------------- //
+void guAlbumBrowser::OnKeyDown( wxKeyEvent &event )
+{
+    //guLogMessage( wxT( "OnKeyDown %i" ), event.GetKeyCode() );
+    int CurPos = m_NavSlider->GetValue();
+    int KeyCode = event.GetKeyCode();
+    switch( KeyCode )
+    {
+        case WXK_HOME :
+            CurPos = m_NavSlider->GetMin();
+            break;
+
+        case WXK_END :
+            CurPos = m_NavSlider->GetMax();
+            break;
+
+        case WXK_DOWN :
+        case WXK_RIGHT :
+        case WXK_NUMPAD_DOWN :
+            CurPos++;
+            break;
+
+        case WXK_UP :
+        case WXK_LEFT :
+        case WXK_NUMPAD_UP :
+            CurPos--;
+            break;
+
+        case WXK_PAGEDOWN :
+        case WXK_NUMPAD_PAGEDOWN :
+            CurPos += m_NavSlider->GetPageSize();
+            break;
+
+        case WXK_PAGEUP :
+        case WXK_NUMPAD_PAGEUP :
+            CurPos -= m_NavSlider->GetPageSize();
+            break;
+    }
+
+    if( CurPos > m_NavSlider->GetMax() )
+        CurPos = m_NavSlider->GetMax();
+
+    if( CurPos < m_NavSlider->GetMin() )
+        CurPos = m_NavSlider->GetMin();
+
+    m_NavSlider->SetValue( CurPos );
+
+    wxScrollEvent ScrollEvent( wxEVT_SCROLL_CHANGED );
+    ScrollEvent.SetPosition( CurPos );
+    wxPostEvent( m_NavSlider, ScrollEvent );
+
+    event.Skip();
+}
+
 // -------------------------------------------------------------------------------- //
 void guAlbumBrowser::OnMouseWheel( wxMouseEvent& event )
 {
@@ -1579,6 +1640,9 @@ void guAlbumBrowser::OnBitmapClicked( guAlbumBrowserItem * albumitem, const wxPo
         m_MainSizer->Show( m_BigCoverSizer, true );
 
         Layout();
+
+        wxCommandEvent event( wxEVT_COMMAND_MENU_SELECTED, ID_MAINFRAME_UPDATE_SELINFO );
+        AddPendingEvent( event );
     }
 }
 
@@ -1707,6 +1771,10 @@ void guAlbumBrowser::DoBackToAlbums( void )
     m_MainSizer->Hide( m_BigCoverSizer, true );
     m_MainSizer->Show( m_AlbumBrowserSizer, true );
     Layout();
+    m_NavSlider->SetFocus();
+
+    wxCommandEvent event( wxEVT_COMMAND_MENU_SELECTED, ID_MAINFRAME_UPDATE_SELINFO );
+    AddPendingEvent( event );
 }
 
 // -------------------------------------------------------------------------------- //
@@ -2322,7 +2390,7 @@ void guAlbumBrowser::OnBigCoverTracksPlaylistSave( wxCommandEvent &event )
 {
     guTrackArray Tracks;
     GetSelectedTracks( &Tracks );
-    if( Tracks.Count() );
+    if( Tracks.Count() )
     {
         wxArrayInt TrackIds;
         int Index;
@@ -2383,6 +2451,26 @@ void guAlbumBrowser::OnBigCoverTracksSmartPlaylist( wxCommandEvent &event )
     }
 }
 
+// -------------------------------------------------------------------------------- //
+wxString guAlbumBrowser::GetSelInfo( void )
+{
+    if( m_BigCoverShowed )
+    {
+        return wxString::Format( wxT( "%u " ), m_BigCoverTracks.Count() ) + _( "Tracks" );
+    }
+    else
+    {
+        if( m_AlbumsCount > 0 )
+        {
+            wxString SelInfo = _( "Albums" ) + wxString::Format( wxT( " %u " ), m_ItemStart + 1 );
+            SelInfo += _( "to" ) + wxString::Format( wxT( " %u " ), guMin( m_ItemStart + m_ItemCount, m_AlbumsCount ) );
+            SelInfo += _( "of" ) + wxString::Format( wxT( " %u " ), m_AlbumsCount );
+            return SelInfo;
+        }
+    }
+    return wxEmptyString;
+}
+
 
 
 
