@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -280,6 +280,7 @@ enum guCommandIds {
     ID_RADIO_ENQUEUE_AFTER_ARTIST,
     ID_RADIO_DOUPDATE,
     ID_RADIO_UPDATED,
+    ID_RADIO_CREATE_TREE_ITEM,
     ID_RADIO_UPDATE_END,
     ID_RADIO_GENRE_ADD,
     ID_RADIO_GENRE_EDIT,
@@ -310,6 +311,7 @@ enum guCommandIds {
     ID_PLAYERPANEL_TRACKLISTCHANGED,
     ID_PLAYERPANEL_PLAYMODECHANGED,
     ID_PLAYERPANEL_VOLUMECHANGED,
+    ID_PLAYERPANEL_SEEKED,
     ID_PLAYERPANEL_SETRATING_0,
     ID_PLAYERPANEL_SETRATING_1,
     ID_PLAYERPANEL_SETRATING_2,
