@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -48,6 +48,7 @@ guCopyToAction::guCopyToAction()
 // -------------------------------------------------------------------------------- //
 guCopyToAction::guCopyToAction( guTrackArray * tracks, guMediaViewer * mediaviewer, const wxString &destdir, const wxString &pattern, int format, int quality, bool movefiles )
 {
+    guLogMessage( wxT( "guCopyToAction %i files : delete = %i" ), tracks->Count(), movefiles );
     m_Type = guCOPYTO_ACTION_COPYTO;
     m_Tracks = tracks;
     m_MediaViewer = mediaviewer;
@@ -86,6 +87,7 @@ guCopyToAction::guCopyToAction( guTrackArray * tracks, guMediaViewer * mediaview
     m_Format = mediaviewer->TranscodeFormat();
     m_Quality = mediaviewer->TranscodeQuality();
     m_DestDir = mediaviewer->AudioPath();
+    m_MoveFiles = mediaviewer->MoveFiles();
     if( m_DestDir.EndsWith( wxT( "//" ) ) )
         m_DestDir.RemoveLast();
     else if( !m_DestDir.EndsWith( wxT( "/" ) ) )
@@ -114,6 +116,7 @@ guCopyToAction::guCopyToAction( wxString * playlistpath, guMediaViewer * mediavi
     m_Format = mediaviewer->TranscodeFormat();
     m_Quality = mediaviewer->TranscodeQuality();
     m_Pattern = mediaviewer->Pattern();
+    m_MoveFiles = mediaviewer->MoveFiles();
     m_DestDir = mediaviewer->AudioPath();
 //    wxArrayString AudioFolders = wxStringTokenize( PortableMediaDevice->AudioFolders(), wxT( "," ) );
 //    m_DestDir += AudioFolders[ 0 ].Trim( true ).Trim( false );
@@ -197,6 +200,7 @@ guCopyToThread::~guCopyToThread()
 // -------------------------------------------------------------------------------- //
 void guCopyToThread::AddAction( guTrackArray * tracks, guMediaViewer * mediaviewer, const wxString &destdir, const wxString &pattern, int format, int quality, bool movefiles )
 {
+    guLogMessage( wxT( "AddAction %i files : delete = %i" ), tracks->Count(), movefiles );
     guCopyToAction * CopyToAction = new guCopyToAction( tracks, mediaviewer, destdir, pattern, format, quality, movefiles );
     if( CopyToAction )
     {
@@ -392,6 +396,7 @@ void guCopyToThread::DoCopyToAction( guCopyToAction &copytoaction )
 
             FileName = DestDir + guExpandTrackMacros( FilePattern, CurTrack, m_CurrentFile - 1 );
 
+            // TODO : Check target file system and filter the appropiate characters for every file system
             // Replace all the special chars <>:" / \ | ? *
             wxRegEx RegEx( wxT( "[<>:\\|?*]" ) );
             RegEx.ReplaceAll( &FileName, wxT( "_" ) );
@@ -826,6 +831,14 @@ void guCopyToThread::DoCopyToAction( guCopyToAction &copytoaction )
         wxCommandEvent Event( wxEVT_COMMAND_MENU_SELECTED, MediaViewer->GetBaseCommand() + guCOLLECTION_ACTION_UPDATE_LIBRARY );
         wxPostEvent( MediaViewer, Event );
     }
+    else
+    {
+        if( m_DeleteTracks.Count() )
+        {
+            MediaViewer = m_MainFrame->GetDefaultMediaViewer();
+            MediaViewer->DeleteTracks( &m_DeleteTracks );
+        }
+    }
 }
 
 // -------------------------------------------------------------------------------- //
