@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -33,8 +33,6 @@
 #include <wx/dir.h>
 #include <wx/dynarray.h>
 
-// wxSqlite3
-#include "wx/wxsqlite3.h"
 
 #define GU_TRACKS_QUERYSTR   wxT( "SELECT song_id, song_name, song_genreid, song_genre, song_artistid, song_artist, "\
                "song_albumartistid, song_albumartist, song_composerid, song_composer, song_albumid, song_album, "\
@@ -43,6 +41,9 @@
                "song_addedtime, song_lastplay, song_filesize "\
                "FROM songs " )
 
+#define GUCOVER_THUMB_SIZE      38
+#define GUCOVER_IMAGE_SIZE      100
+
 // PLAYLISTS
 #define guPLAYLIST_TYPE_STATIC       0
 #define guPLAYLIST_TYPE_DYNAMIC      1
@@ -133,7 +134,7 @@ class guTrack
         m_CoverId = 0;
     };
 
-    ~guTrack() {};
+    virtual ~guTrack() {};
 
     bool ReadFromFile( const wxString &file );
 
@@ -226,9 +227,10 @@ class guAlbumItem : public guListItem
 WX_DECLARE_OBJARRAY(guAlbumItem,guAlbumItems);
 
 enum guRadioSource {
-    guRADIO_SOURCE_GENRE = 0,
+    guRADIO_SOURCE_SHOUTCAST_GENRE = 0,
     guRADIO_SOURCE_USER,
-    guRADIO_SOURCE_SEARCH
+    guRADIO_SOURCE_SHOUTCAST_SEARCH,
+    guRADIO_SOURCE_TUNEIN
 };
 
 enum guTRACKS_ORDER {
