@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -653,6 +653,9 @@ guDynPlayListEditor::guDynPlayListEditor( wxWindow * parent, guDynPlayList * pla
         m_SortCheckBox->Connect( wxEVT_COMMAND_CHECKBOX_CLICKED, wxCommandEventHandler( guDynPlayListEditor::OnSortChecked ), NULL, this );
 	}
 	m_NameTextCtrl->Connect( wxEVT_COMMAND_TEXT_UPDATED, wxCommandEventHandler( guDynPlayListEditor::OnNameChanged ), NULL, this );
+	m_LengthHours->Connect( wxEVT_COMMAND_SPINCTRL_UPDATED, wxSpinEventHandler( guDynPlayListEditor::OnHoursChanged ), NULL, this );
+	m_LengthMinutes->Connect( wxEVT_COMMAND_SPINCTRL_UPDATED, wxSpinEventHandler( guDynPlayListEditor::OnMinutesChanged ), NULL, this );
+	m_LengthSeconds->Connect( wxEVT_COMMAND_SPINCTRL_UPDATED, wxSpinEventHandler( guDynPlayListEditor::OnSecondsChanged ), NULL, this );
 
 	m_FiltersListBox->SetFocus();
 }
@@ -1097,3 +1100,21 @@ void guDynPlayListEditor::OnNameChanged( wxCommandEvent &event )
 }
 
 // -------------------------------------------------------------------------------- //
+void guDynPlayListEditor::OnHoursChanged( wxSpinEvent &event )
+{
+    m_FilterAccept->Enable( m_CurFilter != wxNOT_FOUND );
+}
+
+// -------------------------------------------------------------------------------- //
+void guDynPlayListEditor::OnMinutesChanged( wxSpinEvent &event )
+{
+    m_FilterAccept->Enable( m_CurFilter != wxNOT_FOUND );
+}
+
+// -------------------------------------------------------------------------------- //
+void guDynPlayListEditor::OnSecondsChanged( wxSpinEvent &event )
+{
+    m_FilterAccept->Enable( m_CurFilter != wxNOT_FOUND );
+}
+
+// -------------------------------------------------------------------------------- //
