@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -1267,7 +1267,7 @@ int guFilesListBox::GetTracksFromFiles( const wxArrayString &files, guTrackArray
         for( Index = 0; Index < Count; Index++ )
         {
             wxString FileName = files[ Index ];
-            //guLogMessage( wxT( "File: %s" ), FileName.c_str() );
+            //guLogMessage( wxT( "GetTracksFromFiles: %s" ), FileName.c_str() );
             wxURI Uri( FileName );
 
             if( Uri.IsReference() )
@@ -1457,7 +1457,7 @@ bool guFilesListBox::GetCounters( wxLongLong * count, wxLongLong * len, wxLongLo
     Count = m_Files.Count();
     for( Index = 0; Index < Count; Index++ )
     {
-        if( ( m_Files[ Index ].m_Type == guFILEITEM_TYPE_FOLDER ) )
+        if( m_Files[ Index ].m_Type == guFILEITEM_TYPE_FOLDER )
         {
             if( ( m_Files[ Index ].m_Name != wxT( ".." ) ) )
                 ( * len )++;
@@ -1642,7 +1642,7 @@ void guFileBrowser::OnDirItemChanged( wxTreeEvent &event )
 
     guLogMessage( wxT( "guFileBrowser::OnDirItemChanged( '%s' )" ), CurPath.c_str() );
 
-    if( m_DirCtrl->GetShowPaths() && guFILEBROWSER_SHOWPATH_LOCATIONS )
+    if( m_DirCtrl->GetShowPaths() & guFILEBROWSER_SHOWPATH_LOCATIONS )
     {
         m_MediaViewer = FindMediaViewerByPath( m_MainFrame, CurPath );
         m_Db = m_MediaViewer ? m_MediaViewer->GetDb() : NULL;
@@ -1978,8 +1978,7 @@ void guFileBrowser::OnFolderSaveToPlayList( wxCommandEvent &event )
                 }
             }
 
-            wxCommandEvent evt( wxEVT_COMMAND_MENU_SELECTED, ID_PLAYLIST_UPDATED );
-            wxPostEvent( m_MainFrame, evt );
+            m_MediaViewer->UpdatePlaylists();
         }
 
         PlayListAppendDlg->Destroy();
@@ -2116,8 +2115,7 @@ void guFileBrowser::OnItemsSaveToPlayList( wxCommandEvent &event )
                 }
             }
 
-            wxCommandEvent evt( wxEVT_COMMAND_MENU_SELECTED, ID_PLAYLIST_UPDATED );
-            wxPostEvent( m_MainFrame, evt );
+            m_MediaViewer->UpdatePlaylists();
         }
 
         PlayListAppendDlg->Destroy();
@@ -2131,7 +2129,7 @@ void guFileBrowser::OnItemsCopyTo( wxCommandEvent &event )
     m_FilesCtrl->GetSelectedSongs( Tracks );
 
     int Index = event.GetId() - ID_COPYTO_BASE;
-    if( Index > guCOPYTO_DEVICE_BASE )
+    if( Index >= guCOPYTO_DEVICE_BASE )
     {
         Index -= guCOPYTO_DEVICE_BASE;
         event.SetId( ID_MAINFRAME_COPYTODEVICE_TRACKS );
