@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -75,6 +75,7 @@
 #include "./images/tiny_search_again.h"
 #include "./images/tiny_search_engine.h"
 #include "./images/tiny_shoutcast.h"
+#include "./images/tiny_tunein.h"
 #include "./images/tiny_status_error.h"
 #include "./images/tiny_status_pending.h"
 #include "./images/track.h"
@@ -248,6 +249,7 @@ guImage_Item guImage_Items[] = {
     GUIMAGE( guImage_tiny_doc_save,                 wxBITMAP_TYPE_PNG ),
     GUIMAGE( guImage_tiny_reload,                   wxBITMAP_TYPE_PNG ),
     GUIMAGE( guImage_tiny_shoutcast,                wxBITMAP_TYPE_PNG ),
+    GUIMAGE( guImage_tiny_tunein,                   wxBITMAP_TYPE_PNG ),
     GUIMAGE( guImage_tiny_net_radio,                wxBITMAP_TYPE_PNG ),
     GUIMAGE( guImage_tiny_left,                     wxBITMAP_TYPE_PNG ),
     GUIMAGE( guImage_tiny_right,                    wxBITMAP_TYPE_PNG ),
