@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -149,7 +149,7 @@ wxString guLastFMRequest::DoRequest( const bool AddSign, const bool IsGetAction
 
                 if( !RetVal.IsEmpty() )
                 {
-                    DbCache->SetContent( UrlStr, RetVal );
+                    DbCache->SetContent( UrlStr, RetVal, guDBCACHE_TYPE_LASTFM );
                 }
 
                 free( Buffer );
