@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -257,7 +257,7 @@ class guDownloadImageThread : public wxThread
   public:
     guDownloadImageThread( guLastFMPanel * lastfmpanel, guFetchLastFMInfoThread * mainthread,
             guDbCache * dbcache, int index, const wxChar * imageurl, int commandid,
-            void * commanddata, wxImage ** pimage, const int imagesize = guDBCACHE_IMAGE_SIZE_TINY );
+            void * commanddata, wxImage ** pimage, const int imagesize = guDBCACHE_TYPE_IMAGE_SIZE_TINY );
     ~guDownloadImageThread();
 
     virtual ExitCode Entry();
