@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -385,10 +385,13 @@ guLibUpdateThread::ExitCode guLibUpdateThread::Entry()
             {
                 for( ItemIndex = 0; ItemIndex < ItemCount; ItemIndex++ )
                 {
-                    ItemTrackId = m_Db->FindTrackFile( PlayList.GetItem( ItemIndex ).m_Location, NULL );
-                    if( ItemTrackId )
+                    if( wxFileExists( PlayList.GetItem( ItemIndex ).m_Location ) )
                     {
-                        PlayListIds.Add( ItemTrackId );
+                        ItemTrackId = m_Db->FindTrackFile( PlayList.GetItem( ItemIndex ).m_Location, NULL );
+                        if( ItemTrackId )
+                        {
+                            PlayListIds.Add( ItemTrackId );
+                        }
                     }
                 }
                 if( PlayListIds.Count() )
