@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -230,20 +230,23 @@ void guListView::DrawBackground( wxDC &dc, const wxRect &rect, const int row, co
 void guListView::OnContextMenu( wxContextMenuEvent& event )
 {
     wxMenu Menu;
-    wxPoint Point = event.GetPosition();
-    // If from keyboard
-    if( Point.x == -1 && Point.y == -1 )
-    {
-        wxSize Size = GetSize();
-        Point.x = Size.x / 2;
-        Point.y = Size.y / 2;
-    }
-    else
-    {
-        Point = ScreenToClient( Point );
-    }
     CreateContextMenu( &Menu );
-    PopupMenu( &Menu, Point.x, Point.y );
+    if( Menu.GetMenuItemCount() )
+    {
+        wxPoint Point = event.GetPosition();
+        // If from keyboard
+        if( Point.x == -1 && Point.y == -1 )
+        {
+            wxSize Size = GetSize();
+            Point.x = Size.x / 2;
+            Point.y = Size.y / 2;
+        }
+        else
+        {
+            Point = ScreenToClient( Point );
+        }
+        PopupMenu( &Menu, Point.x, Point.y );
+    }
 }
 
 
@@ -1785,6 +1788,11 @@ wxDragResult guListViewDropTarget::OnData( wxCoord x, wxCoord y, wxDragResult de
     if( def == wxDragError || def == wxDragNone || def == wxDragCancel )
         return def;
 
+    if( m_ListView->m_DragSelfItems )
+    {
+        return wxDragNone;
+    }
+
     if( !GetData() )
     {
         guLogMessage( wxT( "Error getting drop data" ) );
@@ -1835,6 +1843,7 @@ wxDragResult guListViewDropTarget::OnData( wxCoord x, wxCoord y, wxDragResult de
 // -------------------------------------------------------------------------------- //
 bool guListViewDropTarget::OnDrop( wxCoord x, wxCoord y )
 {
+    //guLogMessage( wxT( "OnDrop %i / %i" ), m_ListView->m_DragSelfItems, m_ListView->m_DragSelfItemsEnabled );
     // We are moving items inside this object.
     if( m_ListView->m_DragSelfItems )
     {
