@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -46,6 +46,12 @@
 #include <wx/html/htmlwin.h>
 #include <wx/panel.h>
 
+
+// -------------------------------------------------------------------------------- //
+wxString DoExtractTags( const wxString &content, const wxString &begin, const wxString &end );
+wxString DoExtractTag( const wxString &content, const wxString &tag );
+
+
 class guLyricSearchEngine;
 class guLyricSearchContext;
 
