@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -178,7 +178,7 @@ class guMainFrame : public wxFrame
 
     wxMenuItem *                    m_MenuRadios;
     wxMenuItem *                    m_MenuRadTextSearch;
-    wxMenuItem *                    m_MenuRadLabels;
+//    wxMenuItem *                    m_MenuRadLabels;
     wxMenuItem *                    m_MenuRadGenres;
     wxMenuItem *                    m_MenuRadUpdate;
 
@@ -256,6 +256,7 @@ class guMainFrame : public wxFrame
     void                            OnPlayerCapsChanged( wxCommandEvent &event );
     void                            OnPlayerVolumeChanged( wxCommandEvent &event );
     void                            OnAudioScrobbleUpdate( wxCommandEvent &event );
+    void                            OnPlayerSeeked( wxCommandEvent &event );
 
     guMediaViewer *                 FindCollectionMediaViewer( void * windowptr );
 
@@ -413,6 +414,7 @@ class guMainFrame : public wxFrame
     guPodcastPanel *                GetPodcastsPanel( void ) { return m_PodcastsPanel; }
 
 
+    guMediaViewer *                 GetDefaultMediaViewer( void );
     const guMediaCollectionArray &  GetMediaCollections( void ) { wxMutexLocker Locker( m_CollectionsMutex ); return m_Collections; }
     bool                            IsCollectionActive( const wxString &uniqueid );
     bool                            IsCollectionPresent( const wxString &uniqueid );
@@ -422,6 +424,7 @@ class guMainFrame : public wxFrame
 
     void                            OnCloseTab( wxCommandEvent &event );
 
+    void                            DoShowCaptions( const bool visible );
     void                            OnShowCaptions( wxCommandEvent &event );
 
     void                            UpdatePodcasts( void );
