@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -1094,14 +1094,14 @@ bool guMediaCtrl::Stop( void )
 }
 
 // -------------------------------------------------------------------------------- //
-bool guMediaCtrl::Seek( wxFileOffset where )
+bool guMediaCtrl::Seek( wxFileOffset where, const bool accurate )
 {
     guLogDebug( wxT( "guMediaCtrl::Seek( %lli )" ), where );
     bool Result = false;
     Lock();
     if( m_CurrentPlayBin )
     {
-        Result = m_CurrentPlayBin->Seek( where );
+        Result = m_CurrentPlayBin->Seek( where, accurate );
     }
     Unlock();
     return Result;
@@ -1436,19 +1436,41 @@ bool guFaderPlayBin::BuildOutputBin( void )
     };
 
     int OutputDevice = m_Player->OutputDevice();
-    outputsink = gst_element_factory_make( ElementNames[ OutputDevice ], "OutputSink" );
-    if( IsValidElement( outputsink ) )
+    if( ( OutputDevice >= guOUTPUT_DEVICE_AUTOMATIC ) && ( OutputDevice < guOUTPUT_DEVICE_OTHER ) )
     {
-        if( OutputDevice > guOUTPUT_DEVICE_GCONF )
+        outputsink = gst_element_factory_make( ElementNames[ OutputDevice ], "OutputSink" );
+        if( IsValidElement( outputsink ) )
         {
-            wxString OutputDeviceName = m_Player->OutputDeviceName();
-            if( !OutputDeviceName.IsEmpty() )
+            if( OutputDevice > guOUTPUT_DEVICE_GCONF )
             {
-                g_object_set( outputsink, "device", ( const char * ) OutputDeviceName.mb_str( wxConvFile ), NULL );
+                wxString OutputDeviceName = m_Player->OutputDeviceName();
+                if( !OutputDeviceName.IsEmpty() )
+                {
+                    g_object_set( outputsink, "device", ( const char * ) OutputDeviceName.mb_str( wxConvFile ), NULL );
+                }
+            }
+            m_OutputSink = outputsink;
+            return true;
+        }
+    }
+    else if( OutputDevice == guOUTPUT_DEVICE_OTHER )
+    {
+        wxString OutputDeviceName = m_Player->OutputDeviceName();
+        if( !OutputDeviceName.IsEmpty() )
+        {
+            GError * err = NULL;
+            outputsink = gst_parse_launch( ( const char * ) OutputDeviceName.mb_str( wxConvFile ), &err );
+            if( outputsink )
+            {
+                if( err )
+                {
+                    guLogMessage( wxT( "Error building output pipeline: '%s'" ), wxString( err->message, wxConvUTF8 ).c_str() );
+                    g_error_free( err );
+                }
+                m_OutputSink = outputsink;
+                return true;
             }
         }
-        m_OutputSink = outputsink;
-        return true;
     }
 
     guLogError( wxT( "The configured audio output sink is not valid. Autoconfiguring..." ) );
@@ -1477,7 +1499,7 @@ bool guFaderPlayBin::BuildPlaybackBin( void )
   {
     //m_Uri =
     g_object_set( m_Playbin, "uri", ( const char * ) m_Uri.mb_str( wxConvFile ), NULL );
-    g_object_set( m_Playbin, "buffer-size", m_Player->BufferSize() * 1024, NULL );
+    g_object_set( m_Playbin, "buffer-size", gint( m_Player->BufferSize() * 1024 ), NULL );
     //g_object_set( m_Playbin, "volume", 1.0, NULL );
 
     m_Playbackbin = gst_bin_new( "playbackbin" );
@@ -1489,19 +1511,18 @@ bool guFaderPlayBin::BuildPlaybackBin( void )
         GstElement * resample = gst_element_factory_make( "audioresample", "pb_audioresampler" );
         if( IsValidElement( resample ) )
         {
+          m_ReplayGain = NULL;
           if( m_Player->m_ReplayGainMode )
           {
             m_ReplayGain = gst_element_factory_make( "rgvolume", "pb_rgvolume" );
           }
-          else
-            m_ReplayGain = NULL;
 
           if( !m_Player->m_ReplayGainMode || IsValidElement( m_ReplayGain ) )
           {
             if( m_ReplayGain )
             {
-              g_object_set( G_OBJECT( m_ReplayGain ), "album-mode", m_Player->m_ReplayGainMode - 1, NULL );
-              g_object_set( G_OBJECT( m_ReplayGain ), "pre-amp", m_Player->m_ReplayGainPreAmp, NULL );
+              g_object_set( G_OBJECT( m_ReplayGain ), "album-mode", gboolean( m_Player->m_ReplayGainMode - 1 ), NULL );
+              g_object_set( G_OBJECT( m_ReplayGain ), "pre-amp", gdouble( m_Player->m_ReplayGainPreAmp ), NULL );
                //g_object_set( G_OBJECT( m_ReplayGain ), "fallback-gain", gdouble( -6 ), NULL );
             }
 
@@ -1510,16 +1531,16 @@ bool guFaderPlayBin::BuildPlaybackBin( void )
             {
               if( m_PlayType == guFADERPLAYBIN_PLAYTYPE_CROSSFADE )
               {
-                g_object_set( m_FaderVolume, "volume", 0.0, NULL );
+                g_object_set( m_FaderVolume, "volume", gdouble( 0.0 ), NULL );
               }
 
               GstElement * level = gst_element_factory_make( "level", "pb_level" );
               if( IsValidElement( level ) )
               {
-                g_object_set( level, "message", TRUE, NULL );
-                g_object_set( level, "interval", 100000000, NULL) ;
-                g_object_set( level, "peak-falloff", 6.0, NULL );
-                g_object_set( level, "peak-ttl", 3 * 300000000, NULL );
+                g_object_set( level, "message", gboolean( true ), NULL );
+                g_object_set( level, "interval", guint64( 100000000 ), NULL) ;
+                g_object_set( level, "peak-falloff", gdouble( 6.0 ), NULL );
+                g_object_set( level, "peak-ttl", guint64( 3 * 300000000 ), NULL );
 
                 m_Volume = gst_element_factory_make( "volume", "pb_volume" );
                 if( IsValidElement( m_Volume ) )
@@ -1566,7 +1587,7 @@ bool guFaderPlayBin::BuildPlaybackBin( void )
 
                                             g_object_set( G_OBJECT( m_Playbin ), "audio-sink", m_Playbackbin, NULL );
 
-                                            g_object_set( G_OBJECT( m_Playbin ), "flags", 0x02 | 0x10, NULL );
+                                            g_object_set( G_OBJECT( m_Playbin ), "flags", GST_PLAY_FLAG_AUDIO | GST_PLAY_FLAG_SOFT_VOLUME, NULL );
 
                                             g_signal_connect( G_OBJECT( m_Playbin ), "about-to-finish",
                                                 G_CALLBACK( gst_about_to_finish ), ( void * ) this );
@@ -1714,9 +1735,9 @@ bool guFaderPlayBin::BuildRecordBin( const wxString &path, GstElement * encoder,
                 if( IsValidElement( queue ) )
                 {
                     // The bin contains elements that change state asynchronously and not as part of a state change in the entire pipeline.
-                    g_object_set( m_RecordBin, "async-handling", true, NULL );
+                    g_object_set( m_RecordBin, "async-handling", gboolean( true ), NULL );
 
-                    g_object_set( queue, "max-size-buffers", 3, NULL );
+                    g_object_set( queue, "max-size-buffers", guint( 3 ), NULL );
                     //g_object_set( queue, "max-size-time", 10 * GST_SECOND, "max-size-buffers", 0, "max-size-bytes", 0, NULL );
 
                     if( muxer )
@@ -1791,7 +1812,7 @@ bool guFaderPlayBin::DoStartSeek( void )
     m_SeekTimerId = 0;
     if( GST_IS_ELEMENT( m_Playbin ) )
     {
-        return Seek( m_StartOffset );
+        return Seek( m_StartOffset, true );
     }
     return false;
 }
@@ -1806,7 +1827,7 @@ void guFaderPlayBin::SendEvent( guMediaEvent &event )
 bool guFaderPlayBin::SetVolume( double volume )
 {
     guLogDebug( wxT( "guFaderPlayBin::SetVolume (%i)  %0.2f" ), m_Id, volume );
-    g_object_set( m_Volume, "volume", volume, NULL );
+    g_object_set( m_Volume, "volume", gdouble( volume ), NULL );
     return true;
 }
 
@@ -1842,7 +1863,7 @@ bool guFaderPlayBin::SetFaderVolume( double volume )
         //guLogDebug( wxT( "guFaderPlayBin::SetFaderVolume (%i)   %0.2f  %i" ), m_Id, volume, m_State == guFADERPLAYBIN_STATE_FADEIN );
         Lock();
         m_LastFadeVolume = volume;
-        g_object_set( m_FaderVolume, "volume", volume, NULL );
+        g_object_set( m_FaderVolume, "volume", gdouble( volume ), NULL );
 
         switch( m_State )
         {
@@ -1926,7 +1947,7 @@ bool guFaderPlayBin::SetEqualizer( const wxArrayInt &eqbands )
 void guFaderPlayBin::SetEqualizerBand( const int band, const int value )
 {
     g_object_set( G_OBJECT( m_Equalizer ), wxString::Format( wxT( "band%u" ),
-            band ).char_str(), gdouble( value ) / 10.0, NULL );
+            band ).char_str(), gdouble( value / 10.0 ), NULL );
 }
 
 // -------------------------------------------------------------------------------- //
@@ -2274,14 +2295,15 @@ bool guFaderPlayBin::Stop( void )
 }
 
 // -------------------------------------------------------------------------------- //
-bool guFaderPlayBin::Seek( wxFileOffset where )
+bool guFaderPlayBin::Seek( wxFileOffset where, bool accurate )
 {
     guLogDebug( wxT( "guFaderPlayBin::Seek (%i) %li )" ), m_Id, where );
 
-    return gst_element_seek_simple( m_Playbin,
-                                    GST_FORMAT_TIME,
-                                    GstSeekFlags( GST_SEEK_FLAG_FLUSH | GST_SEEK_FLAG_KEY_UNIT ),
-                                    where * GST_MSECOND );
+    GstSeekFlags SeekFlags = GstSeekFlags( GST_SEEK_FLAG_FLUSH | GST_SEEK_FLAG_KEY_UNIT );
+    if( accurate )
+        SeekFlags = GstSeekFlags( SeekFlags | GST_SEEK_FLAG_ACCURATE );
+
+    return gst_element_seek_simple( m_Playbin, GST_FORMAT_TIME, SeekFlags, where * GST_MSECOND );
 }
 
 // -------------------------------------------------------------------------------- //
@@ -2289,7 +2311,7 @@ wxFileOffset guFaderPlayBin::Position( void )
 {
     GstFormat Format = GST_FORMAT_TIME;
     wxFileOffset Position;
-    gst_element_query_position( m_OutputSink, &Format, &Position );
+    gst_element_query_position( m_OutputSink, &Format, ( gint64 * ) &Position );
     return Position;
 }
 
@@ -2298,7 +2320,7 @@ wxFileOffset guFaderPlayBin::Length( void )
 {
     GstFormat Format = GST_FORMAT_TIME;
     wxFileOffset Length;
-    gst_element_query_duration( m_OutputSink, &Format, &Length );
+    gst_element_query_duration( m_OutputSink, &Format, ( gint64 * ) &Length );
     return Length;
 }
 
@@ -2309,7 +2331,7 @@ bool guFaderPlayBin::EnableRecord( const wxString &recfile, const int format, co
     GstElement * Encoder = NULL;
     GstElement * Muxer = NULL;
     gint Mp3Quality[] = { 320, 192, 128, 96, 64 };
-    float OggQuality[] = { 0.9, 0.7, 0.5, 0.3, 0.1 };
+    gfloat OggQuality[] = { 0.9f, 0.7f, 0.5f, 0.3f, 0.1f };
     gint FlacQuality[] = { 8, 7, 5, 3, 1 };
 
     //
