@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -447,7 +447,7 @@ void guMediaViewer::SetViewMode( const int mode )
                 if( !m_LibPanel )
                 {
                     CreateLibraryView();
-                    GetSizer()->Add( m_LibPanel, 1, wxEXPAND, 5 );
+                    GetSizer()->Add( m_LibPanel, 1, wxEXPAND|wxALL, 5 );
                 }
                 else
                 {
@@ -461,7 +461,7 @@ void guMediaViewer::SetViewMode( const int mode )
                 if( !m_AlbumBrowser )
                 {
                     CreateAlbumBrowserView();
-                    GetSizer()->Add( m_AlbumBrowser, 1, wxEXPAND, 5 );
+                    GetSizer()->Add( m_AlbumBrowser, 1, wxEXPAND|wxALL, 5 );
 
                     int SelectedFilter = m_FilterChoice->GetSelection();
                     SetFilter( SelectedFilter ? m_DynFilterArray[ SelectedFilter - 1 ] : wxT( "" ) );
@@ -478,7 +478,7 @@ void guMediaViewer::SetViewMode( const int mode )
                 if( !m_TreeViewPanel )
                 {
                     CreateTreeView();
-                    GetSizer()->Add( m_TreeViewPanel, 1, wxEXPAND, 5 );
+                    GetSizer()->Add( m_TreeViewPanel, 1, wxEXPAND|wxALL, 5 );
                 }
                 else
                 {
@@ -492,7 +492,7 @@ void guMediaViewer::SetViewMode( const int mode )
                 if( !m_PlayListPanel )
                 {
                     CreatePlayListView();
-                    GetSizer()->Add( m_PlayListPanel, 1, wxEXPAND, 5 );
+                    GetSizer()->Add( m_PlayListPanel, 1, wxEXPAND|wxALL, 5 );
                 }
                 else
                 {
@@ -1182,25 +1182,18 @@ void guMediaViewer::ImportFiles( guTrackArray * tracks )
 {
     if( tracks )
     {
-        if( tracks->Count() )
+        guImportFiles * ImportFiles = new guImportFiles( this, this, tracks );
+        if( ImportFiles )
         {
-            guImportFiles * ImportFiles = new guImportFiles( this, this, tracks );
-            if( ImportFiles )
+            if( ImportFiles->ShowModal() == wxID_OK  )
             {
-                if( ImportFiles->ShowModal() == wxID_OK  )
-                {
-                    m_MainFrame->ImportFiles( this, tracks, ImportFiles->GetCopyToOption(), ImportFiles->GetCopyToPath() );
-                }
-                else
-                {
-                    delete tracks;
-                }
-                ImportFiles->Destroy();
+                m_MainFrame->ImportFiles( this, tracks, ImportFiles->GetCopyToOption(), ImportFiles->GetCopyToPath() );
             }
-        }
-        else
-        {
-            delete tracks;
+            else
+            {
+                delete tracks;
+            }
+            ImportFiles->Destroy();
         }
     }
 }
@@ -1377,16 +1370,7 @@ wxString guMediaViewer::GetSelInfo( void )
 
         case guMEDIAVIEWER_MODE_ALBUMBROWSER :
         {
-            unsigned int AlbumCount = m_AlbumBrowser->GetAlbumsCount();
-            if( AlbumCount > 0 )
-            {
-                unsigned int ItemStart = m_AlbumBrowser->GetItemStart();
-                wxString SelInfo = _( "Albums" ) + wxString::Format( wxT( " %u " ), ItemStart );
-                SelInfo += _( "to" ) + wxString::Format( wxT( " %u " ), guMin( ItemStart + m_AlbumBrowser->GetItemCount(), AlbumCount ) );
-                SelInfo += _( "of" ) + wxString::Format( wxT( " %u " ), AlbumCount );
-                return SelInfo;
-            }
-            break;
+            return m_AlbumBrowser->GetSelInfo();
         }
 
         case guMEDIAVIEWER_MODE_TREEVIEW :
@@ -1489,8 +1473,7 @@ void guMediaViewer::DownloadAlbumCover( const int albumid )
             wxImage * CoverImage = CoverEditor->GetSelectedCoverImage();
             if( CoverImage )
             {
-                guConfig * Config = ( guConfig * ) guConfig::Get();
-                wxArrayString SearchCovers = Config->ReadAStr( wxT( "Word" ), wxEmptyString, wxT( "coversearch" ) );
+                wxArrayString SearchCovers = GetCoverWords();
                 wxString CoverName = AlbumPath + ( SearchCovers.Count() ? SearchCovers[ 0 ] : wxT( "cover" ) ) + wxT( ".jpg" );
                 CoverImage->SaveFile( CoverName, wxBITMAP_TYPE_JPEG );
 
@@ -2128,6 +2111,16 @@ wxString guMediaViewer::PlaylistPath( void )
     return wxEmptyString;
 }
 
+// -------------------------------------------------------------------------------- //
+bool guMediaViewer::MoveFiles( void )
+{
+    if( m_CopyToPattern )
+    {
+        return m_CopyToPattern->m_MoveFiles;
+    }
+    return false;
+}
+
 // -------------------------------------------------------------------------------- //
 void guMediaViewer::OnSmartAddTracks( wxCommandEvent &event )
 {
