@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -254,7 +254,7 @@ void guPlayList::OnDropBegin( void )
     if( GetItemCount() )
     {
         guConfig * Config = ( guConfig * ) guConfig::Get();
-        if( Config->ReadBool( wxT( "DropFilesClearPlayList" ), false, wxT( "general" ) ) )
+        if( Config->ReadBool( wxT( "DropFilesClearPlaylist" ), false, wxT( "general" ) ) )
         {
             ClearItems();
             RefreshAll();
@@ -307,7 +307,7 @@ void guPlayList::OnDropEnd( void )
     // Once finished send the update guPlayList event to the guPlayList object
     wxCommandEvent event( wxEVT_COMMAND_MENU_SELECTED, ID_PLAYER_PLAYLIST_UPDATELIST );
     guConfig * Config = ( guConfig * ) guConfig::Get();
-    if( Config->ReadBool( wxT( "DropFilesClearPlayList" ), false, wxT( "general" ) ) )
+    if( Config->ReadBool( wxT( "DropFilesClearPlaylist" ), false, wxT( "general" ) ) )
     {
         event.SetExtraLong( 1 );
     }
@@ -374,6 +374,7 @@ void guPlayList::RemoveSelected()
 // -------------------------------------------------------------------------------- //
 void guPlayList::MoveSelection( void )
 {
+    //guLogMessage( wxT( "MoveSelection %i" ), m_DragOverItem );
     //
     // Move the Selected Items to the DragOverItem and DragOverFirst
     //
@@ -694,11 +695,6 @@ void guPlayList::DrawBackground( wxDC &dc, const wxRect &rect, const int row, co
     }
 }
 
-// -------------------------------------------------------------------------------- //
-long guPlayList::GetCount()
-{
-    return m_Items.GetCount();
-}
 
 // -------------------------------------------------------------------------------- //
 wxString guPlayList::OnGetItemText( const int row, const int col ) const
@@ -971,7 +967,7 @@ guTrack * guPlayList::GetPrevAlbum( const int playloop, const bool forceskip )
 guTrack * guPlayList::GetItem( size_t item )
 {
     size_t ItemsCount = m_Items.Count();
-    if( ItemsCount && item >= 0 && item < ItemsCount )
+    if( ItemsCount && item < ItemsCount )
     {
       return &m_Items[ item ];
     }
@@ -1298,16 +1294,25 @@ void guPlayList::AddPlayListItem( const wxString &filename, const int aftercurre
     }
     else if( Uri.IsReference() )    // Its a file
     {
-        if( wxFileExists( filename ) )
+        if( filename.StartsWith( wxT( "file://" ) ) )
         {
-            if( guIsValidAudioFile( filename ) )
+            FileName = wxURI::Unescape( Uri.GetPath() );
+        }
+        else
+        {
+            FileName = filename;
+        }
+        guLogMessage( wxT( "Loading '%s'" ), FileName.c_str() );
+        if( wxFileExists( FileName ) )
+        {
+            if( guIsValidAudioFile( FileName ) )
             {
-                Track.m_FileName = filename;
+                Track.m_FileName = FileName;
 
-                if( !m_Db->FindTrackFile( filename, &Track ) )
+                if( !m_Db->FindTrackFile( FileName, &Track ) )
                 {
                     guDbPodcasts * DbPodcasts = m_MainFrame->GetPodcastsDb();
-                    if( DbPodcasts->GetPodcastItemFile( filename, &PodcastItem ) )
+                    if( DbPodcasts->GetPodcastItemFile( FileName, &PodcastItem ) )
                     {
                         Track.m_Type = guTRACK_TYPE_PODCAST;
                         Track.m_SongId = PodcastItem.m_Id;
@@ -1323,13 +1328,13 @@ void guPlayList::AddPlayListItem( const wxString &filename, const int aftercurre
                     else
                     {
                         //guLogMessage( wxT( "Reading tags from the file..." ) );
-                        if( Track.ReadFromFile( filename ) )
+                        if( Track.ReadFromFile( FileName ) )
                         {
                             Track.m_Type = guTRACK_TYPE_NOTDB;
                         }
                         else
                         {
-                            guLogError( wxT( "Could not read tags from file '%s'" ), filename.c_str() );
+                            guLogError( wxT( "Could not read tags from file '%s'" ), FileName.c_str() );
                         }
                     }
                 }
@@ -1343,9 +1348,9 @@ void guPlayList::AddPlayListItem( const wxString &filename, const int aftercurre
                 guLogError( wxT( "Could not open the file '%s'" ), filename.c_str() );
             }
         }
-        else if( wxDirExists( filename ) )
+        else if( wxDirExists( FileName ) )
         {
-            wxString DirName = filename;
+            wxString DirName = FileName;
             wxDir Dir;
             if( !DirName.EndsWith( wxT( "/" ) ) )
                 DirName += wxT( "/" );
@@ -1708,7 +1713,7 @@ void guPlayList::OnCopyToClicked( wxCommandEvent &event )
     }
 
     int Index = event.GetId() - ID_COPYTO_BASE;
-    if( Index > guCOPYTO_DEVICE_BASE )
+    if( Index >= guCOPYTO_DEVICE_BASE )
     {
         Index -= guCOPYTO_DEVICE_BASE;
         event.SetId( ID_MAINFRAME_COPYTODEVICE_TRACKS );
@@ -2386,7 +2391,7 @@ void guPlayList::OnCommandClicked( wxCommandEvent &event )
                 {
                     for( index = 0; index < count; index++ )
                     {
-                        SongList += wxT( " \"" ) + Track.m_FileName + wxT( "\"" );
+                        SongList += wxT( " \"" ) + m_Items[ Selection[ index ] ].m_FileName + wxT( "\"" );
                     }
                     CurCmd.Replace( wxT( "{tp}" ), SongList.Trim( false ) );
                 }
@@ -2744,8 +2749,9 @@ void guPlayList::LoadPlaylistTracks( void )
         {
             //guLogMessage( wxT( "%u-%u %s" ), Index, MainApp->argc, MainApp->argv[ Index ] );
             AddPlayListItem( MainApp->argv[ Index ], guINSERT_AFTER_CURRENT_NONE, wxNOT_FOUND );
-            m_StartPlaying = true;
         }
+        m_CurItem = wxNOT_FOUND;
+        m_StartPlaying = true;
     }
     else
     {
