@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -79,32 +79,55 @@ bool guPlaylistFile::IsValidPlayList( const wxString &uri )
 // -------------------------------------------------------------------------------- //
 bool guPlaylistFile::Load( const wxString &uri )
 {
+    guLogMessage( wxT( "guPlaylistFile::Load '%s'" ), uri.c_str() );
     wxURI Uri( uri );
+    wxString LowerPath = Uri.GetPath().Lower();
 
     //guLogMessage( wxT( "'%s' IsReference:%i" ), uri.c_str(), Uri.IsReference() );
     if( Uri.IsReference() )
     {
-        wxString PLPath = uri.Lower();
-        if( PLPath.EndsWith( wxT( ".pls" ) ) )
+        wxString FileName;
+        if( uri.StartsWith( wxT( "file://" ) ) )
         {
-            return ReadPlsFile( uri );
+            FileName = wxURI::Unescape( Uri.GetPath() );
         }
-        else if( PLPath.EndsWith( wxT( ".m3u" ) ) )
+        else
         {
-            return ReadM3uFile( uri );
+            FileName = uri;
         }
-        else if( PLPath.EndsWith( wxT( ".xspf" ) ) )
+
+        if( LowerPath.EndsWith( wxT( ".pls" ) ) )
         {
-            return ReadXspfFile( uri );
+            return ReadPlsFile( FileName );
         }
-        else if( PLPath.EndsWith( wxT( ".asx" ) ) )
+        else if( LowerPath.EndsWith( wxT( ".m3u" ) ) )
         {
-            return ReadAsxFile( uri );
+            return ReadM3uFile( FileName );
+        }
+        else if( LowerPath.EndsWith( wxT( ".xspf" ) ) )
+        {
+            return ReadXspfFile( FileName );
+        }
+        else if( LowerPath.EndsWith( wxT( ".asx" ) ) )
+        {
+            return ReadAsxFile( FileName );
         }
     }
     else
     {
-        if( !IsValidPlayList( uri ) )
+        if( LowerPath.EndsWith( wxT( ".ashx" ) ) )
+        {
+            wxString Content = GetUrlContent( uri );
+            guLogMessage( wxT( "Content:\n%s" ), Content.c_str() );
+            wxArrayString PlaylistItems = wxStringTokenize( Content, wxT( "\n" ) );
+            int Index;
+            int Count = PlaylistItems.Count();
+            for( Index = 0; Index < Count; Index++ )
+            {
+                Load( PlaylistItems[ Index ] );
+            }
+        }
+        else if( !IsValidPlayList( LowerPath ) )
         {
             m_Playlist.Add( new guPlaylistItem( uri, uri ) );
             return true;
@@ -117,20 +140,19 @@ bool guPlaylistFile::Load( const wxString &uri )
             {
                 wxStringInputStream Ins( Content );
 
-                wxString PLPath = Uri.GetPath().Lower();
-                if( PLPath.EndsWith( wxT( ".pls" ) ) )
+                if( LowerPath.EndsWith( wxT( ".pls" ) ) )
                 {
                     return ReadPlsStream( Ins );
                 }
-                else if( PLPath.EndsWith( wxT( ".m3u" ) ) )
+                else if( LowerPath.EndsWith( wxT( ".m3u" ) ) )
                 {
                     return ReadM3uStream( Ins );
                 }
-                else if( PLPath.EndsWith( wxT( ".xspf" ) ) )
+                else if( LowerPath.EndsWith( wxT( ".xspf" ) ) )
                 {
                     return ReadXspfStream( Ins );
                 }
-                else if( PLPath.EndsWith( wxT( ".asx" ) ) )
+                else if( LowerPath.EndsWith( wxT( ".asx" ) ) )
                 {
                     return ReadAsxStream( Ins );
                 }
@@ -181,6 +203,7 @@ bool guPlaylistFile::ReadPlsStream( wxInputStream &playlist, const wxString &pat
             int Count;
             if( PlayList->Read( wxT( "numberofentries" ), &Count ) )
             {
+                guLogMessage( wxT( "Found a playlist with %i items" ), Count );
                 if( !Count )
                 {
                     guLogMessage( wxT( "This station playlist is empty" ) );
@@ -231,6 +254,7 @@ bool guPlaylistFile::ReadPlsStream( wxInputStream &playlist, const wxString &pat
 // -------------------------------------------------------------------------------- //
 bool guPlaylistFile::ReadPlsFile( const wxString &filename )
 {
+    guLogMessage( wxT( "ReadPlsFile( '%s' )" ), filename.c_str() );
     wxFileInputStream Ins( filename );
     if( Ins.IsOk() )
     {
@@ -598,6 +622,9 @@ unsigned int RedBookToMTime( const wxString &rbtime )
     guLogMessage( wxT( "RedBookToMTime( '%s' )" ), rbtime.c_str() );
     // 01:23:45
     wxArrayString Sections = wxStringTokenize( rbtime, wxT( ":" ) );
+    if( Sections.Count() != 3 )
+        return 0;
+
     unsigned long Mins;
     unsigned long Secs;
     unsigned long Frames;
@@ -651,6 +678,9 @@ bool guCuePlaylistFile::LoadFromText( const wxString &content )
             guLogMessage( wxT( "'%s'" ), Line.c_str() );
             wxArrayString Keys = wxStringTokenize( Line, wxT( " " ) );
 
+            if( !Keys.Count() )
+                continue;
+
             if( Keys[ 0 ] == wxT( "FILE" ) )
             {
                 if( CurrentTrack == wxNOT_FOUND )
@@ -801,23 +831,31 @@ bool guCuePlaylistFile::Load( const wxString &location )
     if( !location.IsEmpty() )
     {
         wxURI Uri( location );
+        if( location.StartsWith( wxT( "file://" ) ) )
+        {
+            m_Location = wxURI::Unescape( Uri.GetPath() );
+        }
+        else
+        {
+            m_Location = location;
+        }
 
         if( Uri.IsReference() )
         {
-            guLogMessage( wxT( "CuePlaylist from file : '%s'" ), location.c_str() );
+            guLogMessage( wxT( "CuePlaylist from file : '%s'" ), m_Location.c_str() );
 
-            wxFile PlaylistFile( location, wxFile::read );
+            wxFile PlaylistFile( m_Location, wxFile::read );
 
             if( !PlaylistFile.IsOpened() )
             {
-                guLogMessage( wxT( "Could not open '%s'" ), location.c_str() );
+                guLogMessage( wxT( "Could not open '%s'" ), m_Location.c_str() );
                 return false;
             }
 
             int DataSize = PlaylistFile.Length();
             if( !DataSize )
             {
-                guLogMessage( wxT( "Playlist '%s' with 0 length" ), location.c_str() );
+                guLogMessage( wxT( "Playlist '%s' with 0 length" ), m_Location.c_str() );
                 return false;
             }
 
@@ -826,10 +864,23 @@ bool guCuePlaylistFile::Load( const wxString &location )
             {
                 if( PlaylistFile.Read( Buffer, DataSize ) == DataSize )
                 {
-                    for( int Index = 0; Index < DataSize; Index++ )
+                    Content = wxString( Buffer, wxConvAuto() );
+                    if( Content.IsEmpty() )
                     {
-                        Content += Buffer[ Index ];
+                        Content = wxString( Buffer, wxConvUTF8 );
+                        if( Content.IsEmpty() )
+                        {
+                            Content = wxString( Buffer, wxConvISO8859_1 );
+                            if( Content.IsEmpty() )
+                            {
+                                for( int Index = 0; Index < DataSize; Index++ )
+                                {
+                                    Content += Buffer[ Index ];
+                                }
+                            }
+                        }
                     }
+
                 }
                 else
                 {
