@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -299,7 +299,7 @@ void guPLNamesTreeCtrl::OnContextMenu( wxTreeEvent &event )
 
         Menu.AppendSeparator();
 
-        MenuItem = new wxMenuItem( &Menu, ID_MAINFRAME_SET_ALLOW_PLAYLIST, _( "Set as Alow Filter" ), _( "Set this playlist as the allow filter" ) );
+        MenuItem = new wxMenuItem( &Menu, ID_MAINFRAME_SET_ALLOW_PLAYLIST, _( "Set as Allow Filter" ), _( "Set this playlist as the allow filter" ) );
         MenuItem->SetBitmap( guImage( guIMAGE_INDEX_tiny_accept ) );
         Menu.Append( MenuItem );
 
@@ -309,8 +309,15 @@ void guPLNamesTreeCtrl::OnContextMenu( wxTreeEvent &event )
 
         Menu.AppendSeparator();
 
-        guMainFrame * MainFrame = ( guMainFrame * ) wxTheApp->GetTopWindow();
-        MainFrame->CreateCopyToMenu( &Menu );
+        int TrackCount = m_PlayListPanel->GetPlaylistTrackCount();
+        if( TrackCount )
+        {
+            guMainFrame * MainFrame = ( guMainFrame * ) wxTheApp->GetTopWindow();
+            MainFrame->CreateCopyToMenu( &Menu );
+
+
+        }
+
     }
 
     PopupMenu( &Menu, Point );
@@ -674,7 +681,8 @@ wxDragResult guPLNamesDropTarget::OnData( wxCoord x, wxCoord y, wxDragResult def
             m_PLNamesTreeCtrl->OnDropTracks( Tracks );
             m_PLNamesTreeCtrl->OnDropEnd();
 
-            delete Tracks;
+//            if( Tracks )
+//                delete Tracks;
         }
     }
     else if( ReceivedFormat == wxDataFormat( wxDF_FILENAME ) )
@@ -887,7 +895,7 @@ bool guPlayListPanel::DoTextSearch( const wxString &textsearch )
         m_LastSearchString = textsearch; //m_InputTextCtrl->GetLineText( 0 );
         if( !m_LastSearchString.IsEmpty() )
         {
-            if( m_LastSearchString.Length() > 1 )
+            if( m_LastSearchString.Length() > 0 )
             {
                 m_NamesTreeCtrl->m_TextSearchFilter = guSplitWords( m_LastSearchString );
                 m_NamesTreeCtrl->ExpandAll();
@@ -1051,7 +1059,7 @@ void guPlayListPanel::OnPLNamesEditPlaylist( wxCommandEvent &event )
         {
             PlayListEditor->FillPlayListEditData();
             m_Db->UpdateDynamicPlayList( ItemData->GetData(), &DynPlayList );
-            m_NamesTreeCtrl->ReloadItems();
+            m_NamesTreeCtrl->ReloadItems( false );
         }
         PlayListEditor->Destroy();
     }
@@ -1222,8 +1230,9 @@ void guPlayListPanel::OnPLNamesImport( wxCommandEvent &event )
                 wxArrayInt Songs;
                 for( Index = 0; Index < Count; Index++ )
                 {
-                    wxURI Uri( PlayListFile.GetItem( Index ).m_Location );
-                    wxString FileName = Uri.BuildUnescapedURI();
+                    //wxURI Uri( PlayListFile.GetItem( Index ).m_Location );
+                    //wxString FileName = Uri.BuildUnescapedURI();
+                    wxString FileName = PlayListFile.GetItem( Index ).m_Location;
                     if( FileName.StartsWith( wxT( "file:" ) ) )
                         FileName = FileName.Mid( 5 );
                     //guLogMessage( wxT( "Trying to add file '%s'" ), FileName.c_str() );
@@ -1470,7 +1479,7 @@ void guPlayListPanel::OnPLTracksSavePlayListClicked( wxCommandEvent &event )
         }
     }
 
-    if( NewSongs.Count() );
+    if( NewSongs.Count() )
     {
         guListItems PlayLists;
         m_Db->GetPlayLists( &PlayLists, guPLAYLIST_TYPE_STATIC );
@@ -1879,20 +1888,9 @@ void guPlayListPanel::OnPLTracksDeleteDrive( wxCommandEvent &event )
             guTrackArray Tracks;
             m_PLTracksListBox->GetSelectedSongs( &Tracks );
             //
-            m_Db->DeleteLibraryTracks( &Tracks, false );
-            //
-            int Index;
-            int Count = Tracks.Count();
-            for( Index = 0; Index < Count; Index++ )
-            {
-                if( !wxRemoveFile( Tracks[ Index ].m_FileName ) )
-                {
-                    guLogMessage( wxT( "Error deleting '%s'" ), Tracks[ Index ].m_FileName.c_str() );
-                }
-            }
+            m_MediaViewer->DeleteTracks( &Tracks );
 
-            //m_PLTracksListBox->ReloadItems();
-            m_MediaViewer->UpdatedTracks( guUPDATED_TRACKS_MEDIAVIEWER, &Tracks );
+            SendPlayListUpdatedEvent();
         }
     }
 }
