@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -323,7 +323,7 @@ class guPlayerPanel : public wxPanel
     void                        OnPlayListUpdated( wxCommandEvent &event );
     void                        OnPlayListDClick( wxCommandEvent &event );
 
-    void                        LoadMedia( guFADERPLAYBIN_PLAYTYPE playtype );
+    void                        LoadMedia( guFADERPLAYBIN_PLAYTYPE playtype, const bool forceskip = false );
     void                        OnMediaLoaded( guMediaEvent &event );
     void                        OnMediaPlayStarted( void );
     void                        SavePlayedTrack( void );
