@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -94,7 +94,8 @@ int guDbPodcasts::GetPodcastChannels( guPodcastChannelArray * channels )
                "podcastch_author, podcastch_ownername, podcastch_owneremail, "
                "podcastch_category, podcastch_image, "
                "podcastch_downtype, podcastch_downtext, podcastch_allowdel "
-               "FROM podcastchs" );
+               "FROM podcastchs "
+               "ORDER BY podcastch_title" );
 
   dbRes = ExecuteQuery( query );
 
@@ -829,6 +830,18 @@ int guDbPodcasts::GetPodcastFiles( const wxArrayInt &channels, guDataObjectCompo
   return Count;
 }
 
+// -------------------------------------------------------------------------------- //
+void guDbPodcasts::UpdateItemPaths( const wxString &oldpath, const wxString &newpath )
+{
+  wxString query;
+
+  query = wxString::Format( wxT( "UPDATE podcastitems SET podcastitem_file = replace( podcastitem_file, '%s', '%s' )" ),
+            escape_query_str( oldpath ).c_str(), escape_query_str( newpath ).c_str() );
+
+  guLogMessage( wxT( "Updating path: %s" ), query.c_str() );
+  ExecuteUpdate( query );
+}
+
 
 // -------------------------------------------------------------------------------- //
 // guPostcastPanel
