@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -19,6 +19,8 @@
 //
 // -------------------------------------------------------------------------------- //
 #include "StatusBar.h"
+
+#include "AuiNotebook.h"
 #include "Images.h"
 #include "Utils.h"
 #include "Commands.h"
@@ -145,13 +147,16 @@ void guGauge::SetRange( int range )
 // -------------------------------------------------------------------------------- //
 // guStatusBar
 // -------------------------------------------------------------------------------- //
-guStatusBar::guStatusBar( wxWindow * parent ) : wxStatusBar( parent, wxID_ANY )
+guStatusBar::guStatusBar( wxWindow * parent ) :
+    wxStatusBar( parent, wxID_ANY, wxST_SIZEGRIP | wxSB_FLAT )
 {
     m_LastClickAction = guSTATUSBAR_CLICK_ACTION_NONE;
 
     int FieldWidths[] = { -1, guTRACKCOUNT_PANEL_SIZE, guFORCEGAPLESS_PANEL_SIZE, guAUDIOSCROBBLE_PANEL_SIZE };
     SetFieldsCount( 4 );
     SetStatusWidths( 4, FieldWidths );
+    int FieldStyles[] = { wxSB_FLAT, wxSB_FLAT, wxSB_FLAT, wxSB_FLAT };
+    SetStatusStyles( 4, FieldStyles );
 
     guConfig * Config = ( guConfig * ) guConfig::Get();
     Config->RegisterObject( this );
@@ -235,7 +240,7 @@ void guStatusBar::OnSize( wxSizeEvent &event )
     {
         //size = ASBitmap->GetSize();
         GetFieldRect( GetFieldsCount() - 1, rect );
-        m_ASBitmap->Move( rect.x + 3,
+        m_ASBitmap->Move( rect.x + 1,
                         rect.y + 2 );
     }
 
@@ -243,14 +248,14 @@ void guStatusBar::OnSize( wxSizeEvent &event )
     {
         //size = ASBitmap->GetSize();
         GetFieldRect( GetFieldsCount() - 2, rect );
-        m_PlayMode->Move( rect.x + 3,
+        m_PlayMode->Move( rect.x + 1,
                         rect.y + 3 );
     }
 
     if( m_SelInfo )
     {
         GetFieldRect( GetFieldsCount() - 3, rect );
-        m_SelInfo->Move( rect.x + 3, rect.y + 3 );
+        m_SelInfo->Move( rect.x + 1, rect.y + 3 );
     }
 
     event.Skip();
@@ -504,3 +509,19 @@ void guStatusBar::SetSelInfo( const wxString &label )
 }
 
 // -------------------------------------------------------------------------------- //
+void guStatusBar::DrawField( wxDC &dc, int i )
+{
+    wxRect rect;
+    GetFieldRect( i, rect );
+    if( i < ( GetFieldsCount() - 1 ) )
+    {
+        dc.SetPen( m_mediumShadowPen );
+        dc.DrawLine( rect.x + rect.width - 1, rect.y + 1, rect.x + rect.width - 1, rect.y + rect.height - 1 );
+        dc.SetPen( m_hilightPen );
+        dc.DrawLine( rect.x + rect.width, rect.y + 1, rect.x + rect.width, rect.y + rect.height - 1 );
+    }
+
+    DrawFieldText( dc, i );
+}
+
+// -------------------------------------------------------------------------------- //
