@@ -1,5 +1,5 @@
 // -------------------------------------------------------------------------------- //
-//	Copyright (C) 2008-2012 J.Rios
+//	Copyright (C) 2008-2013 J.Rios
 //	anonbeat@gmail.com
 //
 //    This Program is free software; you can redistribute it and/or modify
@@ -921,7 +921,7 @@ bool guTreeViewPanel::DoTextSearch( const wxString &textsearch )
         m_LastSearchString = textsearch; //m_InputTextCtrl->GetLineText( 0 );
         if( !m_LastSearchString.IsEmpty() )
         {
-            if( m_LastSearchString.Length() > 1 )
+            if( m_LastSearchString.Length() > 0 )
             {
                 wxArrayString TextFilters = guSplitWords( m_LastSearchString );
                 m_TreeViewCtrl->SetTextFilters( TextFilters );
@@ -1412,7 +1412,7 @@ void guTreeViewPanel::OnTVTracksSavePlayListClicked( wxCommandEvent &event )
         }
     }
 
-    if( NewSongs.Count() );
+    if( NewSongs.Count() )
     {
         guListItems PlayLists;
         m_Db->GetPlayLists( &PlayLists, guPLAYLIST_TYPE_STATIC );
@@ -1813,8 +1813,9 @@ void guTreeViewPanel::OnTVTracksDeleteDrive( wxCommandEvent &event )
 // -------------------------------------------------------------------------------- //
 void guTreeViewPanel::SendPlayListUpdatedEvent( void )
 {
-    wxCommandEvent evt( wxEVT_COMMAND_MENU_SELECTED, ID_PLAYLIST_UPDATED );
-    wxPostEvent( wxTheApp->GetTopWindow(), evt );
+//    wxCommandEvent evt( wxEVT_COMMAND_MENU_SELECTED, ID_PLAYLIST_UPDATED );
+//    wxPostEvent( wxTheApp->GetTopWindow(), evt );
+    m_MediaViewer->UpdatePlaylists();
 }
 
 // -------------------------------------------------------------------------------- //
